"""just test import"""

import londiste


def test_one():
    assert londiste

